#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 json-ast
version:              0.3.1
visibility:           public
id:                   json-ast-0.3.1-IAG54kcBkhmCKe8VFqKze3
key:                  json-ast-0.3.1-IAG54kcBkhmCKe8VFqKze3
license:              MIT
copyright:            (c) 2016, Nikita Volkov
maintainer:           Nikita Volkov <nikita.y.volkov@mail.ru>
author:               Nikita Volkov <nikita.y.volkov@mail.ru>
homepage:             https://github.com/nikita-volkov/json-ast 
synopsis:             Universal JSON AST datastructure
abi:                  cda398da4417e40d4b321fa1b0b68358
exposed:              True
exposed-modules:      JSONAST
import-dirs:          /usr/lib/ghc-8.10.5/site-local/json-ast-0.3.1
library-dirs:         /usr/lib/ghc-8.10.5/site-local/json-ast-0.3.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/i386-linux-ghc-8.10.5/json-ast-0.3.1
hs-libraries:         HSjson-ast-0.3.1-IAG54kcBkhmCKe8VFqKze3
depends:
    base-4.14.2.0 scientific-0.3.7.0-Fi0gRGhsiJ35wgbCjOXuHX
    text-1.2.4.1 unordered-containers-0.2.14.0-JpdjDmlqBJN4PAu3jIj4Ya
    vector-0.12.3.0-K9OZS5OCy7cE2QKQqSO9mp

haddock-interfaces:   /usr/share/doc/haskell-json-ast/html/json-ast.haddock
haddock-html:         /usr/share/doc/haskell-json-ast/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

